@@ -35,3 +35,13 @@ class Sort(Enum):
 class Order(Enum):
     ASCENDING = "asc"
     DESCENDING = "desc"
+
+
+class Rank(Enum):
+    RECRUIT = "RECRUIT"
+    COMMONER = "COMMONER"
+    SOLDIER = "SOLDIER"
+    SERGEANT = "SERGEANT"
+    OFFICER = "OFFICER"
+    COLONEL = "COLONEL"
+    LEADER = "LEADER"
